function data = load_inter_data(filename)

% LOAD_INTER_DATA
%
% data = load_inter_data(filename);
%
% Loads data from the specified intermediate file and returns it in a
% structure with the following fields:
%
% comments = all comments/headers as a text string
% data = time series data
% 

disp(['   load_inter_data loading ',filename]);
if ~exist(filename,'file') % give up if there's no file matching
    disp(['    load_inter_data: cannot find ',filename])
    data = NaN;
    return
else 
    % data
    data.data = load(filename);
    
    % other stuff
    data.channel_name = deblank(read_comment_value_from_data_file(filename,'ChannelName:','%s')); % channel name
    data.comments = load_comments(filename,''); % comments
    data.fs = read_comment_value_from_data_file(filename,'SampleRate:','%f'); % sampling frequency
    dt = 1/data.fs; % timestep
    N = length(data.data) - 1; % number of timesteps
    duration = N*dt; % duration of timeseries
    data.time = linspace(0,duration,N+1); % time
    data.h = read_comment_value_from_data_file(filename,'StillWaterDepth:','%f'); % still water depth
    data.units = read_comment_value_from_data_file(filename,'CalibrationUnits:','%s'); % units
    data.x = read_comment_value_from_data_file(filename,'X:','%f'); % x (cross-shore)
    data.y = read_comment_value_from_data_file(filename,'Y:','%f'); % y (alongshore)
    data.z = read_comment_value_from_data_file(filename,'Z:','%f'); % z (vertical)
end

% done
disp('   load_inter_data done');
end