function [H,T,t] = pick_n_waves(time,eta,n)

% PICK_N_WAVES
%
% [H,T,t] = pick_n_waves(time,eta,n);
%
% Zero upcrossing analysis to find 'n' waves in the provided signal 'eta' (m)
% as a function of 'time' (yeardays).  Returns n values of wave height 'H' (m),
% period 'T' (s), and  time 't' (s).  Values chosen are from the
% waves closest to the median wave, in an effort to pick when the wavemaker
% is not ramping up or down.
%
% SEE ALSO: FIND_WAVES

% find the waves
[~,H_all,T_all,t_all] = find_waves(time,eta);

% find the waves
indices = [];
limit = 0.02; % start with 2% threshold
H_median = max(H_all); % median wave
while length(indices) < n && limit < 0.25
    chosen_waves = find(abs(H_median - H_all) < limit*H_median);
    indices = chosen_waves(1):chosen_waves(end);
    limit = limit + 0.01; % increase threshold by 1%
end

% if we got too many, crop to middle n waves
tick = 0;
while length(indices) > n
    if tick
        indices = indices(1:end-1);
    else
        indices = indices(2:end);
    end
    tick = ~tick;
end

% grab the waves in the middle
H = H_all(indices);
T = T_all(indices);
t = t_all(indices);

% done
end

