function c = speed_of_sound(temperature);

% SPEED_OF_SOUND
%
% c = speed_of_sound(temperature);
%
% Returns the speed of sound 'c' (m/s) in water for the specified
% 'temperature' (C) of water.  Assumes pure fresh water at atmospheric
% pressure and shallow depth.
%
% Ref: Marczak, "Water as a standard in the measurements of speed of sound 
% in liquids", JASA., Vol. 102, No. 5, Pt. 1, Nov. 1997, pp 2776-2779.

C0 = 1.402385e3;
C1 = 5.038813;
C2 = -5.799136e-2;
C3 = 3.287156e-4;
C4 = -1.398845e-6;
C5 = 2.787860e-9;

c = C0 + C1*temperature + C2*temperature.^2 + C3*temperature.^3 + C4*temperature.^4 + C5*temperature.^5;