function h = find_still_water(data)

% FIND_STILL_WATER_DEPTH
%
% h = find_still_water(data)
%
% Looks for appropritate analog data channels in 'data' and uses them to 
% generate an estimate of still water depth 'h' (m).

h = 0;
nh = 0;
if isfield(data,'channelnames') && ~isempty(data.channelnames)
    Nc = length(data.channelnames);
    for nc = 1:Nc
        channelname = data.channelnames{nc};
        if strcmp(channelname,'level')
            disp('      find_still_water_depth: level found')
            h = h + mean(data.(channelname).analog(data.(channelname).zero_range));
            h = h + data.(channelname).z; % level has a z location
            nh = nh + 1;
        elseif strcmp(channelname,'depth')
            disp('      find_still_water_depth: depth found')
            h = h + mean(data.(channelname).analog(data.(channelname).zero_range));
            nh = nh + 1;
        end
    end
end
if nh == 0
    disp('      find_still_water_depth: could not find depth or level')
    h = NaN;
else
    h = h / nh;
end
end
  