function data = find_wmstart(data)

% FIND_WMSTART
%
% data = find_wmstart(data);
%
% For each analog & adv channel in the input 'data' structure, finds the
% associated 'wmstart' data field and creates a new 'zero_range' (initial
% range for zeroing out channels) and 'waves_running_range' (period of wave
% activity).
%
% SEE ALSO: PROCESS_RAW_TRIAL

if isfield(data,'channelnames') && ~isempty(data.channelnames)
    Nc = length(data.channelnames);
    for nc = 1:Nc
        channelname = data.channelnames{nc};
        if isfield(data,channelname)
            if isfield(data.(channelname),'wmstart') % wmstart found
                i_start = find(data.(channelname).wmstart > 1);
                if isempty(i_start)
                    % wmstart not going over 1V, using entire record
                    data.(channelname).zero_range = 1:length(data.(channelname).wmstart);
                    data.(channelname).waves_running_range = data.(channelname).zero_range;
                else
                    % waves running range from first wmstart>1 to last
                    data.(channelname).waves_running_range = i_start(1):i_start(end);
                    if i_start(1) > data.(channelname).fs*20
                        % tossing out filter settlings from zero_range
                        data.(channelname).zero_range = round(data.(channelname).fs*10):i_start(1);
                    else
                        % still water too short, retaining filter settlings
                        data.(channelname).zero_range = 1:i_start(1);
                    end
                end
            else
                % wmstart not found, using entire record
                data.(channelname).zero_range = 1:length(data.(channelname).analog);
                data.(channelname).waves_running_range = data.(channelname).zero_range;
            end
        end
    end
end
if isfield(data,'advnames') && ~isempty(data.advnames)
    Nadv = length(data.advnames);
    for nadv = 1:Nadv
        advname = data.advnames{nadv};
        if isfield(data,advname)
            if isfield(data.(advname),'wmstart') % wmstart found
                i_start = find(data.(advname).wmstart > 1);
                if isempty(i_start)
                    % wmstart not going over 1V, using entire record
                    data.(advname).waves_running_range = 1:length(data.(advname).wmstart);
                else
                    data.(advname).waves_running_range = i_start; % process period with wmstart>1
                end
            else
                % wmstart not found, using entire record
                data.(advname).zero_range = 1:size(data.(advname).vel,1);
                data.(advname).waves_running_range = data.(advname).zero_range;
            end
        end
    end
end

end