function comments=load_comments(fname,stopdelimiter);

% LOAD_COMMENTS
%
% comments=load_comments(fname,stopdelimiter);
%
% Loads %-delimited comments from the specified file.  Assumes that data
% is delimited by a final comment line and does not include that
% in the returned comments.  Also stops at the provided stopdelimiter.
%
% Used by HWRL data processing to preserve comments across processing stages.
%
% Final comment lines supported are:
% '%[Data]'
% '% [Data]'

fid=fopen(fname);
comments='';
found=0;
while ~found
    tline=fgetl(fid);
    if tline==-1 % end of file, stop
        found=1;
    elseif ~strfind(tline,'%') % comments are over, stop
        found=1;
    elseif isempty(strfind(tline,'%')) % comments are over, stop
        found=1;
    elseif strfind(tline,'%[Data]') % don't write the data header yet, stop
        found=1;
    elseif strfind(tline,'% [Data]') % don't write the data header yet, stop
        found=1;
    elseif ~isempty(stopdelimiter) % if stopdelimiter is specified
        if strfind(tline,stopdelimiter) % found stopdelimiter, stop
            found=1;
        else % no stopdelimiter found, scan a line
            comments=sprintf('%s\r',[comments,tline]);
        end
    else % scan a line
        comments=sprintf('%s\r',[comments,tline]);
    end
end
fclose(fid);

return