function data_located = locate_raw_data(data_raw,instr_loc)

% LOCATE_RAW_DATA
%
% data_located = locate_raw_data(data_raw,instr_loc);
%
% Locates the raw data in 'data_raw' with the values in 'instr_loc',
% and returns the located data in 'data_located'.
%
% SEE ALSO: LOAD_INSTRUMENT_LOCATIONS, PROCESS_RAW_TRIAL

% setup
disp('      locate_raw_data: starting')
data_located = data_raw;

% locate analog data
if isfield(data_raw,'channelnames')
    Nc = length(data_raw.channelnames); % number of channels
    for nc = 1:Nc
        channelname = data_raw.channelnames{nc}; % channel name
        if isfield(data_raw,channelname) % we have data for this channel name
            channel_timestamp = data_raw.(channelname).startdatenum + mean(data_raw.(channelname).time)/86400;
            if isfield(instr_loc,channelname)
                % we have a location for this channel
                instr_loc_index = find(channel_timestamp - instr_loc.(channelname).time > 0,1,'last'); % pick the most recent instrument location
                if isempty(instr_loc_index) % we didn't find a location prior to the timestamp
                    instr_loc_index = 1; % take the first location
                end
                data_located.(channelname).x = instr_loc.(channelname).x(instr_loc_index); % x
                data_located.(channelname).y = instr_loc.(channelname).y(instr_loc_index); % y
                data_located.(channelname).z = instr_loc.(channelname).z(instr_loc_index); % z
            else
                % we don't have a location for this channel
                data_located.(channelname).x = NaN; % x
                data_located.(channelname).y = NaN; % y
                data_located.(channelname).z = NaN; % z
            end
        end
    end
end

% locate adv data
if isfield(data_raw,'advnames')
    Nadv = length(data_raw.advnames); % number of advs
    for nadv = 1:Nadv
        advname = data_raw.advnames{nadv}; % adv name;
        if isfield(data_raw,advname) % we have data for this adv
            adv_timestamp = data_raw.(advname).startdatenum + mean(data_raw.(advname).time)/86400;
            if isfield(instr_loc,advname)
                % we have a location for this adv
                instr_loc_index = find(adv_timestamp - instr_loc.(advname).time > 0,1,'last'); % pick the most recent instrument location
                if isempty(instr_loc_index) % we didn't find a location prior to the timestamp
                    instr_loc_index = 1; % take the first location
                end
                data_located.(advname).x = instr_loc.(advname).x(instr_loc_index); % x
                data_located.(advname).y = instr_loc.(advname).y(instr_loc_index); % y
                data_located.(advname).z = instr_loc.(advname).z(instr_loc_index); % z
                data_located.(advname).i = instr_loc.(advname).i(instr_loc_index); % i
                data_located.(advname).j = instr_loc.(advname).j(instr_loc_index); % j
                data_located.(advname).k = instr_loc.(advname).k(instr_loc_index); % k
            else
                % we don't have a location for this adv
                data_located.(advname).x = NaN; % x
                data_located.(advname).y = NaN; % y
                data_located.(advname).z = NaN; % z
            end
        end
    end
end

% done
disp('      locate_raw_data: done')
return