function file_timestamp = parse_file_timestamp(fname,prefix)

% PARSE_FILE_TIMESTAMP
%
% file_timestamp = parse_file_timestamp(fname,prefix);
%
% Parses the timestamp of the filename provided, using the given prefix
% as an indicator of where to find the timestamp in the file name.
%
% Accepted timestamp formats are 'yyyymmdd', 'yyyy_mm_dd', and
% 'yyyymmdd_HHMM'

% get the time from the filename
t_start = strfind(fname,prefix) + length(prefix) + 1;
t_end = strfind(fname,'.xls') - 1;
if t_end - t_start + 1 == 8 % yyyyMMdd
    file_timestamp = convertTo(datetime(fname(t_start:t_end),'InputFormat','yyyyMMdd'),'datenum');
elseif t_end - t_start + 1 == 10 % yyyy_MM_dd
    file_timestamp = convertTo(datetime(fname(t_start:t_end),'InputFormat','yyyy_MM_dd'),'datenum');
elseif t_end - t_start + 1 == 13 % yyyyMMdd_HHmm
    file_timestamp = convertTo(datetime(fname(t_start:t_end),'InputFormat','yyyyMMdd_HHmm'),'datenum');
elseif t_end - t_start + 1 == 15 % yyyy_MM_dd_HHmm
    file_timestamp = convertTo(datetime(fname(t_start:t_end),'InputFormat','yyyy_MM_dd_HHmm'),'datenum');
else % ??? use the file modification date
    disp(['   parse_file_timestamp: cannot recognize timestamp of ',fname])
    file_timestamp = NaN;
end

% done
end