function options = process_raw_options(varargin)

% PROCESS_RAW_OPTIONS
%
% options = process_raw_options;
% options = process_raw_options('CalRemoveZeroOffsets','WG_AND_USWG');
%
% Generates default 'options' structure for processing raw data.
%
% SEE ALSO: PROCESS_RAW_EXPERIMENT, PROCESS_RAW_TRIAL

% defaults
options = process_raw_defaults;

if nargin > 0 % handle additional options in name/value pairs
    for n = 1:2:nargin
        if n+1 <= nargin % ensure we don't exceed nargin
            options.(varargin{n}) = varargin{n+1};
        end
    end
end

end

function options = process_raw_defaults
% share, year, project, experiment
options.ShareName = '/Volumes/cce_wrl/';
%options.Year = char(datetime('today'),'yyyy');
%options.ProjectName = 'DefaultProject';
%options.ExperimentName = 'DefaultExperiment';

% logging
options.Diary = 'ON'; % ON or OFF

% save data (ON or OFF)
options.SaveTXT = 'ON'; % ASCII .TXT files
options.SaveMAT = 'ON'; % MATLAB .MAT files
options.SaveWaveLab = 'ON'; % WaveLab3-compatible .DAT files

% calibration
options.CalRemoveZeroOffsets = 'WG_AND_USWG'; % WG_ONLY, WG_AND_USWG, ALL, NONE
options.CalInterpolation = 'WG_AND_USWG'; % WG_ONLY, WG_AND_USWG, ALL, NONE
options.CropData = 'WAVES_RUNNING'; % WAVES_RUNNING, EXCLUDE_STILL_WATER, OFF

% ADVs (Vectrinos)
options.VectrinosUseAmplitudes = 'ON'; % ON or OFF, good for in or out of water ADVs
options.VectrinosUseSNR = 'ON'; % ON or OFF, good for in or out of water ADVs
options.VectrinosUseCorrelations = 'ON'; % ON or OFF, always good
options.VectrinosUsePhaseSpace = 'ON'; % ON or OFF, not good for tsunamis
options.VectrinosSmoothing = 'MEDIUM'; % MILD,MEDIUM,HEAVY,EXTREME,OFF, not good for turbulence at high frequencies
options.VectrinoDefaultTemperature = 20; % default temperature for Vectrinos when none of them are working

% other
options.CleanUpUltrasonicWaveGages = 'ON'; % ON or OFF, always good
end