function value = read_comment_value_from_data_file(filename,comment_name,comment_type_string)

% READ_COMMENT_VALUE_FROM_DATA_FILE
%
% value = read_comment_value_from_data_file(filename,comment_name,comment_type_string);
%
% Reads and returns the value associated with the specified comment_name
% from a data file.  Example, for:
%
% ProjectName: DuneErosion 
% comment_name would be 'ProjectName:', comment_type_string would be '%s'
%
% X: 41.210
% comment_name would be 'X:', comment_type_string would be '%f'
% 
% note for numbers you will want to use cell2mat on the returned value


fid=fopen(filename);
found=0;
while ~found
    tline=fgetl(fid);
    if tline==-1 % can't find it
        disp(['ERROR: cannot find ',comment_name,' in ',filename]);
        value = NaN;
        found=1;
    else
        if contains(tline,comment_name)
            N = length(tline);
            n_colons = strfind(tline,':');
            n = n_colons(1)+1;
            value = textscan(tline(n:N),comment_type_string);
            found=1;
            if contains(comment_type_string,'%s')
                value = value{:};
                str = '';
                for k = 1:length(value)
                    str = [str char(value{k}) ' ']; %#ok<AGROW>
                end
                value = str;
            elseif contains(comment_type_string,'%f')
                value = cell2mat(value);
            elseif contains(comment_type_string,'%d')
                value = cell2mat(value);
            end
        end
    end
end
fclose(fid);
return