function limithit = check_dwb_displacement_limits(t,s,setpoint)

% CHECK_DWB_DISPLACEMENT_LIMITS
%
% limithit = check_dwb_displacement_limits(t,s,setpoint);
%
% Checks wavemaker limits against the supplied board stroke 's' (m) 
% relative to the supplied initial board position 'setpoint' (m) as a 
% function of time 't' (s), for the OSU HWRL DWB.  If a limit is
% exceeded, returns 1, otherwise returns 0.

% timeseries
if size(s,2) == 30 % Nx30
    s_check = s;
elseif size(s,2) == 1 % Nx1
    s_check = repmat(s,1,30); % tile an Nx30
elseif size(s,1) == 30 % 30xN
    s_check = s.'; % flip to Nx30
elseif size(s,1) == 1 % 1xN
    s_check = repmat(s.',1,30); % flip to Nx1 and then tile an Nx30
else
    disp(['check_dwb_displacement_limits: timeseries is ',num2str(size(s,1)),' by ',num2str(size(s,2)),' and I do not recognize it!'])
    s_check = s;
end

% calculate board velocity
v = zeros(size(s_check));
for c_num=1:size(s_check,2) % for each channel
    v(:,c_num) = gradient(s_check(:,c_num),t);
end

% calculate board acceleration
a = zeros(size(v));
for c_num=1:size(s_check,2) % for each channel
    a(:,c_num) = gradient(v(:,c_num),t);
end

if any(abs(s_check(1,:)) > eps)
    disp('DWB wavemaker nonzero start position.')
    limithit = 1;
elseif any(abs(s_check(end,:)) > eps)
    disp('DWB wavemaker nonzero end position.')
    limithit = 1;
elseif any(any(abs(s_check+setpoint) > 1.05))
    disp('DWB wavemaker displacement limit exceeded.')
    limithit = 1;
elseif any(any(abs(diff(s_check,1,2)) > 0.25)) % corrected 12/2/2016
    disp('DWB wavemaker delta displacement limit exceeded.')
    limithit = 1;
elseif any(any(abs(v) > 2))
    disp('DWB wavemaker velocity limit exceeded.')
    limithit = 1;
elseif any(any(abs(a) > 3)) % reduced to 3m/s^2 to prevent servo limits 11/6/2014
    disp('DWB wavemaker acceleration limit exceeded.')
    limithit = 1;
else
    limithit = 0;
end

% done
end
