function limithit = check_lwf_displacement_limits(t,s,setpoint)

% CHECK_LWF_DISPLACEMENT_LIMITS
%
% limithit = check_lwf_displacement_limits(t,s,setpoint);
%
% Checks wavemaker limits against the supplied board stroke 's' (m) 
% relative to the supplied initial board position 'setpoint' (m) as a
% function of time 't' (s), for the OSU HWRL LWF.  If a limit is
% exceeded, returns 1, otherwise returns 0.

% standard gravity
g = gravity;

% calculate board velocity
v = gradient(s,t);

% calculate board acceleration
a = gradient(v,t);

if abs(s(1)) > eps
    disp('LWF wavemaker nonzero start position.')
    limithit = 1;
elseif any(abs(s+setpoint) > 2.1)
    disp('LWF wavemaker stroke displacement limit exceeded.')
    limithit = 1;
elseif any(abs(v) > 3.81)
    disp('LWF wavemaker velocity displacement limit exceeded.')
    limithit = 1;
elseif any(abs(a) > g) % reduced to 1g to prevent deltap limits 10/20/2014
    disp('LWF wavemaker acceleration displacement limit exceeded.')
    limithit = 1;
else
    limithit = 0;
end

return
