function k = dispersion_complex(h,omega,N_evanescent)

% DISPERSION_COMPLEX
%
% k = dispersion_complex(h,omega,N_evanescent);
%
% Numerically solves the linear dispersion relationship for water waves.
% omega^2=gk*tanh(kh); where omega = 2*pi/T; k=2*pi/L; and g is gravity.
% omega (vector) and h (scalar) provided as inputs.
%
% Resulting k is N_evanescent+1 by length(omega) in size.  k(1,:) is real,
% all remaining k(2:Nevanescent+1,:) are imaginary, corresponding to
% the evanescent modes. Iterates using Newton-Raphson.
%
% See also: DISPERSION, DISPERSION_SUMDIF

disp('dispersion_complex: start')

% setup
k = zeros(N_evanescent+1,length(omega));

% real component
k(1,:) = dispersion_p(h,omega);

% imaginary component
k(2:end,:) = 1i*dispersion_e(h,omega,N_evanescent);

% done
disp('dispersion_complex: done')
end
