function [t,s] = error_function_displacement(S,scale_factor)

% ERROR_FUNCTION_DISPLACEMENT
%
% [t,s] = error_function_displacement(S,scale_factor);
%
% Generates a time series 't' (s) of board stroke 's' (m) for an error
% function displacement of input total stroke 'S' (m) and time scale factor
% 'scale_factor' (-).

% find undistorted start time
t = -100:0.001:100;
s = erf(t);
tol = 4.9e-5; % rounds to less than 0.1 mm
tau0 = abs(t(find(s+1>=tol,1,'first'))); % start time

% build time
dt = 0.01; % 100 Hz
t0 = tau0*scale_factor/100; % distorted (stretched) start time
t = -t0:dt:t0; % distorted time
tau = t*100/scale_factor; % undistorted time

% board stroke
s = S/2*erf(tau) + S/2;