function [t,s] = load_dwb_displacement_file(fname)

% LOAD_DWB_DISPLACEMENT_FILE
%
% [t,s] = load_dwb_displacement_file(fname);
%
% Loads the board displacement time series 's' (meters) as a function of
% time 't' (s) from the file 'fname'.  Returns 30 channels of 's',
% one per drive channel of the OSU HWRL DWB wavemaker.
%
% Expects MTS-compatible ASCII format.
%
% See also: SAVE_DWB_DISPLACEMENT_FILE, LOAD_LWF_DISPLACEMENT_FILE

% setup
disp(['load_dwb_displacement_file: ',fname]);
fid = fopen(fname);

% get dt
found=0;
while ~found
    tline=fgetl(fid);
    if tline==-1 % no channel names found
        disp('load_dwb_wave_timeseries_file: can not find dt');
        found=1;
    else
        if strfind(tline,'** ')
            temp = textscan(tline,'** %f');
            dt = temp{:};
            found=1;
        end
    end
end

% get the board displacement values
found=0;
s = [];
while ~found
    tline=fgetl(fid);
    if tline==-1 % done
        found=1;
    else
        temp = textscan(tline,'%f');
        s = [s; temp{:}'];
    end
end

% time
t = 0:dt:(size(s,1)-1)*dt;

% done
disp('load_dwb_displacement_file: done');
fclose(fid);
end