function [t,eta] = load_dwb_wave_timeseries_file(fname)

% LOAD_DWB_WAVE_TIMESERIES_FILE
%
% [t,eta] = load_dwb_wave_timeseries_file(fname);
%
% Loads the free surface time series 'eta_mat' (meters) as a function of
% time 't' (s) from the file 'fname'.  Returns 30 channels of 'eta_mat',
% one per drive channel of the OSU HWRL DWB wavemaker.
%
% Expects MTS-compatible ASCII format.
%
% See also: SAVE_DWB_WAVE_TIMESERIES_FILE, LOAD_LWF_WAVE_TIMESERIES_FILE

% setup
disp(['load_dwb_wave_timeseries_file: ',fname]);
fid = fopen(fname);

% get dt
found=0;
while ~found
    tline=fgetl(fid);
    if tline==-1 % no channel names found
        disp('load_dwb_wave_timeseries_file: can not find dt');
        found=1;
    else
        if strfind(tline,'** ')
            temp = textscan(tline,'** %f');
            dt = temp{:};
            found=1;
        end
    end
end

% get the free surface values
found=0;
eta = [];
while ~found
    tline=fgetl(fid);
    if tline==-1 % done
        found=1;
    else
        temp = textscan(tline,'%f');
        eta = [eta; temp{:}'];
    end
end

% time
t = 0:dt:(size(eta,1)-1)*dt;

% done
disp('load_dwb_wave_timeseries_file: done');
fclose(fid);
end