function [t,s] = load_lwf_displacement_file(fname)

% LOAD_LWF_DISPLACEMENT_FILE
%
% [t,s] = load_lwf_displacement_file(fname);
%
% Loads the board displacement time series 's' (meters) as a function of
% time 't' (s) from the file 'fname'.
%
% Expects MTS-compatible ASCII format.
%
% See also: SAVE_LWF_WAVE_TIMESERIES_FILE, LOAD_DWB_WAVE_TIMESERIES_FILE

% load the file
disp(['load_lwf_displacement_file: ',fname]);
fid = fopen(fname);
temp = textscan(fid,'%f','CommentStyle','*');
temp = temp{:};
fclose(fid);

% dt is the first value
dt = temp(1);

% s is the rest
s = temp(2:end)';

% time
t = 0:dt:(length(s)-1)*dt;

% done
disp('load_lwf_displacement_file: done');
end