function [t,eta] = load_lwf_wave_timeseries_file(fname)

% LOAD_LWF_WAVE_TIMESERIES_FILE
%
% [t,eta] = load_lwf_wave_timeseries_file(fname);
%
% Loads the free surface time series 'eta' (meters) as a function of 
% time 't' (s) from the file 'fname'.
%
% Expects MTS-compatible ASCII format.
%
% SEE ALSO: SAVE_LWF_WAVE_TIMESERIES_FILE, LOAD_DWB_WAVE_TIMESERIES_FILE

% load the file
disp(['load_lwf_wave_timeseries_file: ',fname]);
fid = fopen(fname);
temp = textscan(fid,'%f','CommentStyle','*');
temp = temp{:};
fclose(fid);

% dt is the first value
dt = temp(1);

% eta is the rest
eta = temp(2:end)';

% time
t = 0:dt:(length(eta)-1)*dt;

% done
disp('load_lwf_wave_timeseries_file: done');
end