function save_dwb_displacement_file(fname,s,dt)

% SAVE_DWB_DISPLACEMENT_FILE
%
% save_dwb_displacement_file(fname,s,dt);
%
% Saves the displacement 's' (in meters, positive onshore and zero at the
% board neutral position) with timestep 'dt' (s) to the file 'fname'.
% Expects s to be Nx30 but can handle it as Nx1.
%
% Uses MTS-compatible ASCII format. To load this file, you must first use 
% File>>Translate>>Text to Binary... on the OSU Tsunami Wave Generator 
% window for the HWRL DWB controller.
%
% See also: LOAD_DWB_DISPLACEMENT_FILE, SAVE_LWF_DISPLACEMENT_FILE

% setup
fid = fopen(fname,'w');
eol = '\r\n'; % end of line

% initial comments
fprintf(fid,['*',eol]);
fprintf(fid,['* ',datestr(now),eol]);

% column headers
for i=1:30
    fprintf(fid,['* ',num2str(i),': Board #',num2str(i),' Raw Program (m)',eol]);
end

% timestep
fprintf(fid,['** ',num2str(dt,8),eol]);

% timeseries
if size(s,2) == 30 % Nx30
    s_save = s;
elseif size(s,2) == 1 % Nx1
    s_save = repmat(s,1,30);
elseif size(s,1) == 30 % 30xN
    s_save = s';
elseif size(s,1) == 1 % 1xN
    s_save = repmat(s',1,30);
else
    disp(['save_dwb_displacement_file: timeseries is ',num2str(size(s,1)),' by ',num2str(size(s,2)),' and I do not recognize it!'])
    s_save = NaN;
end
if isfinite(s_save)
    for i=1:size(s_save,1)
        fprintf(fid,'%.6f',s_save(i,1));
        for j=2:size(s_save,2)
            fprintf(fid,'\t'); % tab delimiter
            fprintf(fid,'%.6f',s_save(i,j));
        end
        fprintf(fid,eol);
    end
end

% done
fclose(fid);
return