function save_lwf_wave_timeseries_file(fname,eta,dt)

% SAVE_LWF_WAVE_TIMESERIES_FILE
%
% save_lwf_wave_timeseries_file(fname,eta,dt);
%
% Saves the free surface 'eta' (in meters, positive up and zero at the
% still water level) with timestep 'dt' (s) to the file 'fname'.
%
% Uses MTS-compatible ASCII format. To load this file, you must first use 
% File>>Translate>>Text to Binary... on the OSU.2D Wave Generator Controller 
% window for the HWRL LWF controller.
%
% SEE ALSO: LOAD_LWF_WAVE_TIMESERIES_FILE, SAVE_DWB_WAVE_TIMESERIES_FILE

% setup
fid = fopen(fname,'w');
eol = '\r\n'; % end of line

% header
fprintf(fid,['*',eol]);
fprintf(fid,['* ',datestr(now),eol]);
fprintf(fid,['* 1: Wave Elevation (m)',eol]);

% timestep
fprintf(fid,[num2str(dt,8),eol]);

% eta
fprintf(fid,['%.6f',eol],eta);

% done
fclose(fid);
end