function S = shanks_transformation(A)

% SHANKS_TRANSFORMATION
%
% S = shanks_transformation(A);
%
% Applies the Shanks (1955) transformation to the series of sums A, to get
% a faster-converging estimate of the infinite sum.
% 
% https://en.wikipedia.org/wiki/Shanks_transformation

N = length(A);
S = zeros(1,length(A)-2);
for n = 2:N-1
    deltaAn = A(n+1)-A(n);
    deltaAnm1 = A(n)-A(n-1);
    delta2An = (deltaAn - deltaAnm1);
    S(n-1) = A(n+1) - deltaAn^2/delta2An;
end