
%Data from LUPA
led_LUPA = output.shoreADC.led;  
time_LUPA = output.time;         

%Interpolate LUPa data at 100 Hz
t_start = time_LUPA(1);
t_end   = time_LUPA(end);

% New time vector at 100 Hz 
t_vec = (t_start:0.01:t_end)';  
led_low_LUPA = interp1(time_LUPA, led_LUPA, t_vec, 'linear');

led_DAQ = ans.led.analog;
time_DAQ = ans.led.time;

% Interpolate DAQ LED onto same time base 
led_DAQ_interp = interp1(time_DAQ, led_DAQ, t_vec, 'linear', 0);  % 0 padding for out-of-range

%% Cross-correlation
[xc, lags] = xcorr(led_low_LUPA - mean(led_low_LUPA), led_DAQ_interp - mean(led_DAQ_interp), 'coeff');

% Convert lags to time shift
lag_times = lags * 0.01;  % dt = 0.01s for 100 Hz

% Find max correlation and corresponding lag
[max_corr, max_idx] = max(xc);
time_offset = lag_times(max_idx);


fprintf('Max correlation: %.4f at lag = %.4f seconds\n', max_corr, time_offset);

[~, idx_LUPA_align] = min(abs(t_vec - (t_vec(1) + time_offset)));

% Report actual LUPA time at max correlation alignment
time_at_max_corr = t_vec(idx_LUPA_align);
fprintf('Maximum correlation occurs around LUPA time = %.3f s\n', time_at_max_corr);

figure
plot(output.time,output.shoreADC.led);
hold on;
plot(ans.led.time+time_offset,ans.led.analog)
