function data = quicklook_lupa(dr,trialname)

% QUICKLOOK_LUPA
%
% quicklook_lupa(expname,trialname);
%
% Generates a quick plot and statistics for the specified raw trial.
%
% SEE ALSO: PROCESS_RAW_TRIAL, PROCESS_RAW_EXPERIMENT

% setup
options = process_raw_options; 
options.ShareName = dr;
%options.ProjectName = 'TEAMERMTULUPA5';
%options.ExperimentName = expname;
options.Diary = 'OFF'; % OFF, no diary for quicklooks
options.SaveTXT = 'OFF'; % OFF, we are not saving any data for quicklooks
options.SaveMAT = 'ON'; % OFF, we are not saving any data for quicklooks
options.SaveWaveLab = 'OFF'; % OFF, we are not saving any data for quicklooks
options.CropData = 'OFF'; % OFF, show us all the data
options.VectrinoDefaultTemperature = 9; % measured January 2025

disp(['quicklook_raw_trial for project ',trialname]);
close all

% load instrument locations
instr_loc = load_instrument_locations(options.ShareName);

% load calibration slopes offsets and units
calibrations = load_calibrations(options.ShareName);

% get trial data
data = process_raw_trial(trialname,calibrations,instr_loc,options);

% make some plots
if isstruct(data)
    % from here below we just make a plot

    % plot standard, led, wmstart, awastart
    options.newfig = 1; % new figure
    options.subplotN = 3; % 3 subplots
    options.subplotn = 1; % subplot 1
    options.title = 'Voltages';
    options.ylabel = 'V'; % ylabel
    channelnames = {'standard'};
    quickplot(data,channelnames,options);
    options.subplotn = 2; % subplot 2
    options.newfig = 0; % same figure
    channelnames = {'wmstart','awastart'};
    quickplot(data,channelnames,options);
    options.subplotn = 3; % subplot 3
    options.newfig = 0; % same figure
    channelnames = {'led'};
    quickplot(data,channelnames,options);

    % plot wmdisp, level
    options.newfig = 1; % new figure
    options.subplotN = 2; % 2 subplots
    options.subplotn = 1; % subplot 1
    options.title = 'Water level, board displacement';
    options.ylabel = 'h (m)'; % ylabel
    channelnames = {'level'};
    quickplot(data,channelnames,options);
    options.subplotn = 2; % subplot 2
    options.newfig = 0; % same figure
    channelnames = {'wmdisp'};
    options.ylabel = 's (m)'; % ylabel
    quickplot(data,channelnames,options);

    % plot wave gauges in groups
    % wavemaker,wg1-7,uswg1-4
    options.newfig = 1; % new figure
    options.subplotN = 3; % 3 subplots
    options.subplotn = 1; % subplot 1
    options.title = 'Wave gauges';
    options.ylabel = '\eta (m)'; % ylabel
    channelnames = {'wmwg','wg1','wg2'};
    quickplot(data,channelnames,options);
    options.subplotn = 2; % subplot 2
    options.newfig = 0; % same figure
    channelnames = {'wg3','wg6'};
    quickplot(data,channelnames,options);
    options.subplotn = 3; % subplot 3
    options.newfig = 0; % same figure
    channelnames = {'wg4','wg5'};
    quickplot(data,channelnames,options);
end

% done
disp('quicklook_raw_trial done')
end

function quickplot(data,channelnames,options)
% plot some stuff

% create a new figure if desired
if options.newfig
    figure
end

% create a subplot if desired
% currently only supports subplots in (N,1,n) format
if options.subplotN
    if options.subplotn
        subplot(options.subplotN,1,options.subplotn);
    else
        subplot(options.subplotN,1,1);
    end
end

% plot each channel
N = length(channelnames); % number of channels to plot
nplot = 0;
for n=1:N
    channelname = channelnames{n}; % this channel name
    if isfield(data,channelname) % if it exists
        % plot the channel
        if contains(channelname,'adv') % if this is an adv
            plot(data.(channelname).time,data.(channelname).u); % only plots u at this time
        else % must be an analog channel
            if strcmp(channelname,'level')
                plot(data.(channelname).time,data.(channelname).analog+data.(channelname).z);
            else
                plot(data.(channelname).time,data.(channelname).analog);
            end
        end
        nplot = nplot + 1; % increment the plot count
        if nplot == 1
            % our first plot
            hold on;
        end
    end
end

% add labels and legends
if ~options.subplotN || options.subplotn == 1
    % either the first subplot or the only plot at all, make a title
    title(options.title);
end
ylabel(options.ylabel); % ylabel
legend(channelnames); % legend
if ~options.subplotN || options.subplotn == options.subplotN
    % either the last subplot or the only plot at all
    % make an xlabel and a legend
    xlabel('time (s)');
end
end
